@@ -4,6 +4,8 @@
 
 import os, sys, re, json, argparse, time, logging, inspect, traceback, atexit, argcomplete
 
+#sys.path.append('..')
+
 from io import StringIO
 from datetime import datetime, date
 from collections import namedtuple
@@ -250,6 +252,16 @@ class Argue(object):
 			self.addMethod(_command, operations, m)
 		return
 
+	def getTipe(self, a):
+		#print(a)
+		if ':' in a: 
+			parts = a.split(':')
+			tipe = eval(parts[-1])
+			a = parts[0]
+		else:
+			tipe = str
+		return (a,tipe)
+		
 	def addMethod(self, _command, operations, method):
 		"""
 		private method to add an operation or class method
@@ -293,14 +305,18 @@ class Argue(object):
 					_operation.parameters[n] = p
 					#print(n,p)
 
+			#print(_operation.parameters)
 			for a in _args:
+				(a, tipe) = self.getTipe(a)
 				if a in _operation.parameters.keys():
 					p = _operation.parameters[a]
 					p.positional = True
+					p.type = tipe
 					__args, __kwargs = self.addArgument(p)
 					operation.add_argument(*__args, **__kwargs)
 
 			for a in _kwargs.keys():
+				(a, tipe) = self.getTipe(a)
 				if a in _operation.parameters.keys():
 					p = _operation.parameters[a]
 					if p.oneof:
@@ -420,30 +436,14 @@ class Argue(object):
 		usage: @args.command(<Command>...)
 		where the class Command defines the parameters to the decorator call
 		"""
-
-		# todo, store and review children before building args
-
-		def _wrapit(fn):
-			
-			fn = getRoot(fn)
-			self.addCommand(Command(fn, ckwargs))
-
-			@wraps(fn)
-			def _wrapper(*args, **kwargs):
-				# self.logger.info(self.report(fn,args,kwargs))
-				return fn(*args, **kwargs)
-
-			_wrapper.__bases__ = (fn, )
-
-			return _wrapper
-
-		if len(cargs) == 0:
-			def _actualWrapper(fn):
-				return _wrapit(fn)
-			return _actualWrapper
-		else:
-			fn = cargs[0]
+		
+		def _wrapit(Cls):
+			self.addCommand(Command(Cls, ckwargs))
+			return Cls
+		
+		def _actualWrapper(fn):
 			return _wrapit(fn)
+		return _actualWrapper
 
 	def property(self, *fargs, **fkwargs):
 		"""
@@ -616,6 +616,7 @@ class Argue(object):
 		return self.parsed
 
 	def getValue(self, params, name):
+		name = name.split(':')[0]
 		if hasattr(params[name], 'oneof') and params[name].oneof:
 			for o in params[name].oneof:
 				v = getattr(self.parsed, o)
@@ -659,9 +660,11 @@ class Argue(object):
 				__kwargs = dict()
 
 				for arg in _args:
+					arg = arg.split(':')[0]
 					__args.append(self.getValue(params, arg))
 
 				for key, value in _kwargs.items():
+					key = key.split(':')[0]
 					__kwargs[key] = self.getValue(params, key) or value
 
 				# if hasattr(command,'__del__'): atexit.register(command.__del__)
